// *******************************************************************
// File    : ThumbNail.cs 
// Author  : Igor Tolmachev
// Email   : info@itsamples.com
// Web     : www.itsamples.com 
// You are free to use/modify this code but leave this header intact.
// *******************************************************************

using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Drawing.Imaging;
using System.Data;
using System.Windows.Forms;
using System.IO;
using System.Reflection;
using Microsoft.Win32;

namespace ThumbViewer
{
	/// <summary>
	/// Summary description for ThumbNail.
	/// </summary>
	
	public class ThumbNail : System.Windows.Forms.UserControl
	{
		public System.Windows.Forms.PictureBox pictureBox;
		private System.Windows.Forms.Label labelFileName;
		private System.Windows.Forms.Label labelImageSize;
		/// <summary> 
		/// Required designer variable.
		/// </summary>
		#region Fields
		private System.Drawing.Image m_Image = null;
        public bool m_bOpenFile = false;
        public String m_strFilePath = "";
        #endregion

		public ThumbNail(String strFile, Image pImage, Size xyImage)
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();
            
            ToolTip toolTip = new ToolTip();

            // Set up the delays for the ToolTip.
            toolTip.AutoPopDelay = 5000;
            toolTip.InitialDelay = 1000;
            toolTip.BackColor = Color.Peru;
            toolTip.ForeColor = Color.Black;
            toolTip.ReshowDelay = 500;
            // Force the ToolTip text to be displayed whether or not the form is active.
            toolTip.ShowAlways = true;

            if (pImage != null) 
			{
				//  
                m_Image = (Image)pImage.Clone();
                this.pictureBox.Image = m_Image;
            }
            
            this.labelFileName.Text = strFile;
            if (pImage != null)
            {
                xyImage.Height = pImage.Height;
                xyImage.Width = pImage.Width;
                this.labelImageSize.Text = string.Format("{0} x {1}", xyImage.Width, xyImage.Height);
            }
            else
                this.labelImageSize.Text = string.Format("expected: {0} x {1}", Math.Min(96, xyImage.Width), Math.Min(96,xyImage.Height));

            String strTip = "File: "+strFile + "\n";
            if (this.labelImageSize.Text.IndexOf("expected") == -1)
                strTip += "Size: " + this.labelImageSize.Text;
            else
                strTip += "Size " + this.labelImageSize.Text;
            
            // Set up the ToolTip text for the Button and Checkbox.
            toolTip.SetToolTip(this.pictureBox, strTip);
            
		}

        /// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(m_Image != null)
					m_Image.Dispose();
			}

			base.Dispose( disposing );
		}

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.labelFileName = new System.Windows.Forms.Label();
            this.labelImageSize = new System.Windows.Forms.Label();
            this.pictureBox = new System.Windows.Forms.PictureBox();
            ((System.ComponentModel.ISupportInitialize)(this.pictureBox)).BeginInit();
            this.SuspendLayout();
            // 
            // labelFileName
            // 
            this.labelFileName.BackColor = System.Drawing.Color.LightSteelBlue;
            this.labelFileName.ForeColor = System.Drawing.Color.Black;
            this.labelFileName.Location = new System.Drawing.Point(1, 129);
            this.labelFileName.Name = "labelFileName";
            this.labelFileName.Size = new System.Drawing.Size(128, 20);
            this.labelFileName.TabIndex = 3;
            this.labelFileName.Text = "Filename";
            this.labelFileName.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            // 
            // labelImageSize
            // 
            this.labelImageSize.BackColor = System.Drawing.Color.SlateGray;
            this.labelImageSize.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(204)));
            this.labelImageSize.ForeColor = System.Drawing.Color.Black;
            this.labelImageSize.Location = new System.Drawing.Point(1, 149);
            this.labelImageSize.Name = "labelImageSize";
            this.labelImageSize.Size = new System.Drawing.Size(128, 20);
            this.labelImageSize.TabIndex = 4;
            this.labelImageSize.Text = "Image Size";
            this.labelImageSize.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            // 
            // pictureBox
            // 
            this.pictureBox.BackColor = System.Drawing.Color.WhiteSmoke;
            this.pictureBox.BackgroundImageLayout = System.Windows.Forms.ImageLayout.Center;
            this.pictureBox.Cursor = System.Windows.Forms.Cursors.Hand;
            this.pictureBox.ErrorImage = global::ThumbViewer.Properties.Resources.Empty;
            this.pictureBox.Image = global::ThumbViewer.Properties.Resources.Empty;
            this.pictureBox.ImeMode = System.Windows.Forms.ImeMode.NoControl;
            this.pictureBox.Location = new System.Drawing.Point(1, 1);
            this.pictureBox.Name = "pictureBox";
            this.pictureBox.Size = new System.Drawing.Size(128, 128);
            this.pictureBox.SizeMode = System.Windows.Forms.PictureBoxSizeMode.CenterImage;
            this.pictureBox.TabIndex = 2;
            this.pictureBox.TabStop = false;
            this.pictureBox.Click += new System.EventHandler(this.OnThumbnail);
            // 
            // ThumbNail
            // 
            this.BackColor = System.Drawing.Color.Navy;
            this.Controls.Add(this.labelImageSize);
            this.Controls.Add(this.labelFileName);
            this.Controls.Add(this.pictureBox);
            this.Name = "ThumbNail";
            this.Size = new System.Drawing.Size(130, 170);
            ((System.ComponentModel.ISupportInitialize)(this.pictureBox)).EndInit();
            this.ResumeLayout(false);

		}
		#endregion

        private void OnThumbnail(object sender, EventArgs e)
        {
            if (this.m_bOpenFile)
            {
                if (File.Exists(m_strFilePath + this.labelFileName.Text))
                {
                    System.Diagnostics.Process.Start(m_strFilePath + this.labelFileName.Text);
                }
            }
        }
	}
}
